==> narui_core-0.1.0.crate: narui_core-0.1.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

## 0.1.0 (2021-11-19)

Initial release!

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 21 commits contributed to the release over the course of 80 calendar days.
 - 0 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release rutter_layout v0.1.0, narui_core v0.1.0, narui_macros v0.1.0, narui_widgets v0.1.0, narui v0.1.0 ([`dc18edd`](https://github.comgit//apertus-open-source-cinema/narui/commit/dc18edd7b636abfd9815716d9a3b0d297f2179e9))
    - Release freelist v0.1.0, rutter_layout v0.1.0, narui_core v0.1.0, narui_macros v0.1.0, narui_widgets v0.1.0, narui v0.1.0 ([`5b90685`](https://github.comgit//apertus-open-source-cinema/narui/commit/5b9068543940621cf046f0dbd8d84cad0b9bfa3d))
    - Release freelist v0.1.0, rutter_layout v0.1.0, narui_core v0.1.0, narui_macros v0.1.0, narui_widgets v0.1.0, narui v0.1.0 ([`974b403`](https://github.comgit//apertus-open-source-cinema/narui/commit/974b40366ec6bcd43a6c32883f117b7ca45753d8))
    - Release freelist v0.1.0, rutter_layout v0.1.0, narui_core v0.1.0, narui_macros v0.1.0, narui_widgets v0.1.0, narui v0.1.0 ([`86eb164`](https://github.comgit//apertus-open-source-cinema/narui/commit/86eb1640fe543d25e0e8842181aac6e9b392fe63))
    - use best device for our requirements ([`deb6ae7`](https://github.comgit//apertus-open-source-cinema/narui/commit/deb6ae780b4a97258f4dc521d7280b7baff33090))
    - add metadata to Cargo.toml files ([`23cb406`](https://github.comgit//apertus-open-source-cinema/narui/commit/23cb406809d31613caa3457eaa983e81b349eab6))
    - upgrade vulkano rs to 0.26.0 ([`30a2797`](https://github.comgit//apertus-open-source-cinema/narui/commit/30a2797815ef0b1ca38e782a8387c816732de1a4))
    - Rework macro imports ([`99bffa7`](https://github.comgit//apertus-open-source-cinema/narui/commit/99bffa76b373f2191ee2e50d425642905708961d))
    - Implement subpasses ([`a60d2d6`](https://github.comgit//apertus-open-source-cinema/narui/commit/a60d2d66b18ce49a05ec3e6491592f04de2e6e39))
    - optimize widget gen to use Option instead of Rc ([`dfdba3c`](https://github.comgit//apertus-open-source-cinema/narui/commit/dfdba3cb18815672cd94f586621039eaf2c90dff))
    - fix compiling on stable rust ([`5f12191`](https://github.comgit//apertus-open-source-cinema/narui/commit/5f1219183a04b820fb8d4581467574d77ed0c690))
    - rework proc macros to not generate as many macros ([`38a6439`](https://github.comgit//apertus-open-source-cinema/narui/commit/38a64396b94a5b8e23fdc1d8ab47f14ffcff29b7))
    - directly overwrite args, do not create a new Box ([`b78bf62`](https://github.comgit//apertus-open-source-cinema/narui/commit/b78bf620a205e5ce1d0fda22de36a3343e3fa9d2))
    - implement correct (render) sorting for text ([`1aa92c5`](https://github.comgit//apertus-open-source-cinema/narui/commit/1aa92c534b1ef55750e7002d84a1da81ab413fdc))
    - optimize KeyMap even further ([`b9a799e`](https://github.comgit//apertus-open-source-cinema/narui/commit/b9a799e87c1b79a34d77f73bbe807f1053b2f0f4))
    - optimize KeyMap slightly using HashMap::entry ([`ba3b6a0`](https://github.comgit//apertus-open-source-cinema/narui/commit/ba3b6a005e802e458b1713f9df90ef04de331f35))
    - update and cleanup deps ([`0f08af9`](https://github.comgit//apertus-open-source-cinema/narui/commit/0f08af9ca7e7a5f67eea20549b8a5322770fc30e))
    - remove jemallocator ([`f471cc0`](https://github.comgit//apertus-open-source-cinema/narui/commit/f471cc09d922290f7ad0637f9a8252bdf61e8570))
    - slight optimization of shout_args ([`80b3792`](https://github.comgit//apertus-open-source-cinema/narui/commit/80b37926fb1774c15d8810dcecdbb9874dee4110))
    - render lyon, text and rounded rect single pass ([`4ad6232`](https://github.comgit//apertus-open-source-cinema/narui/commit/4ad623252ed3c4bbeccdc74a7ecd6d6cf77981fa))
    - refactoring ([`16f0955`](https://github.comgit//apertus-open-source-cinema/narui/commit/16f0955fc104936fc29627c6bb29567e73ebe664))
</details>

==> narui_core-0.1.1.crate: narui_core-0.1.1/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

## 0.1.1 (2021-12-13)

minor fixes for better compatibility

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 4 commits contributed to the release over the course of 14 calendar days.
 - 0 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Adjusting changelogs prior to release of narui_core v0.1.1, narui_widgets v0.1.1 ([`7e51058`](https://github.comgit//apertus-open-source-cinema/narui/commit/7e51058be8960873da3d46b53d7ed99d5840d438))
    - switch to 4 sample anti-aliasing ([`cdcc471`](https://github.comgit//apertus-open-source-cinema/narui/commit/cdcc471f2c0952dbe5bce789bfae72f1bf3897a6))
    - upgrade vulcano-rs to 0.27.0 ([`a4ec9f9`](https://github.comgit//apertus-open-source-cinema/narui/commit/a4ec9f992b405a6b832045f581e06d9b41f80c71))
    - do not eagerly acquire new swapchain images ([`6b78d9b`](https://github.comgit//apertus-open-source-cinema/narui/commit/6b78d9b28b59cd563fe6d2b351ddeff47c23359c))
</details>

## 0.1.0 (2021-11-19)

Initial release!

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 22 commits contributed to the release over the course of 80 calendar days.
 - 0 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release narui_core v0.1.0, narui_macros v0.1.0, narui_widgets v0.1.0, narui v0.1.0 ([`ded0884`](https://github.comgit//apertus-open-source-cinema/narui/commit/ded08846593b06955d2413823f439a7436189eae))
    - Release rutter_layout v0.1.0, narui_core v0.1.0, narui_macros v0.1.0, narui_widgets v0.1.0, narui v0.1.0 ([`dc18edd`](https://github.comgit//apertus-open-source-cinema/narui/commit/dc18edd7b636abfd9815716d9a3b0d297f2179e9))
    - Release freelist v0.1.0, rutter_layout v0.1.0, narui_core v0.1.0, narui_macros v0.1.0, narui_widgets v0.1.0, narui v0.1.0 ([`5b90685`](https://github.comgit//apertus-open-source-cinema/narui/commit/5b9068543940621cf046f0dbd8d84cad0b9bfa3d))
    - Release freelist v0.1.0, rutter_layout v0.1.0, narui_core v0.1.0, narui_macros v0.1.0, narui_widgets v0.1.0, narui v0.1.0 ([`974b403`](https://github.comgit//apertus-open-source-cinema/narui/commit/974b40366ec6bcd43a6c32883f117b7ca45753d8))
    - Release freelist v0.1.0, rutter_layout v0.1.0, narui_core v0.1.0, narui_macros v0.1.0, narui_widgets v0.1.0, narui v0.1.0 ([`86eb164`](https://github.comgit//apertus-open-source-cinema/narui/commit/86eb1640fe543d25e0e8842181aac6e9b392fe63))
    - use best device for our requirements ([`deb6ae7`](https://github.comgit//apertus-open-source-cinema/narui/commit/deb6ae780b4a97258f4dc521d7280b7baff33090))
    - add metadata to Cargo.toml files ([`23cb406`](https://github.comgit//apertus-open-source-cinema/narui/commit/23cb406809d31613caa3457eaa983e81b349eab6))
    - upgrade vulkano rs to 0.26.0 ([`30a2797`](https://github.comgit//apertus-open-source-cinema/narui/commit/30a2797815ef0b1ca38e782a8387c816732de1a4))
    - Rework macro imports ([`99bffa7`](https://github.comgit//apertus-open-source-cinema/narui/commit/99bffa76b373f2191ee2e50d425642905708961d))
    - Implement subpasses ([`a60d2d6`](https://github.comgit//apertus-open-source-cinema/narui/commit/a60d2d66b18ce49a05ec3e6491592f04de2e6e39))
    - optimize widget gen to use Option instead of Rc ([`dfdba3c`](https://github.comgit//apertus-open-source-cinema/narui/commit/dfdba3cb18815672cd94f586621039eaf2c90dff))
    - fix compiling on stable rust ([`5f12191`](https://github.comgit//apertus-open-source-cinema/narui/commit/5f1219183a04b820fb8d4581467574d77ed0c690))
    - rework proc macros to not generate as many macros ([`38a6439`](https://github.comgit//apertus-open-source-cinema/narui/commit/38a64396b94a5b8e23fdc1d8ab47f14ffcff29b7))
    - directly overwrite args, do not create a new Box ([`b78bf62`](https://github.comgit//apertus-open-source-cinema/narui/commit/b78bf620a205e5ce1d0fda22de36a3343e3fa9d2))
    - implement correct (render) sorting for text ([`1aa92c5`](https://github.comgit//apertus-open-source-cinema/narui/commit/1aa92c534b1ef55750e7002d84a1da81ab413fdc))
    - optimize KeyMap even further ([`b9a799e`](https://github.comgit//apertus-open-source-cinema/narui/commit/b9a799e87c1b79a34d77f73bbe807f1053b2f0f4))
    - optimize KeyMap slightly using HashMap::entry ([`ba3b6a0`](https://github.comgit//apertus-open-source-cinema/narui/commit/ba3b6a005e802e458b1713f9df90ef04de331f35))
    - update and cleanup deps ([`0f08af9`](https://github.comgit//apertus-open-source-cinema/narui/commit/0f08af9ca7e7a5f67eea20549b8a5322770fc30e))
    - remove jemallocator ([`f471cc0`](https://github.comgit//apertus-open-source-cinema/narui/commit/f471cc09d922290f7ad0637f9a8252bdf61e8570))
    - slight optimization of shout_args ([`80b3792`](https://github.comgit//apertus-open-source-cinema/narui/commit/80b37926fb1774c15d8810dcecdbb9874dee4110))
    - render lyon, text and rounded rect single pass ([`4ad6232`](https://github.comgit//apertus-open-source-cinema/narui/commit/4ad623252ed3c4bbeccdc74a7ecd6d6cf77981fa))
    - refactoring ([`16f0955`](https://github.comgit//apertus-open-source-cinema/narui/commit/16f0955fc104936fc29627c6bb29567e73ebe664))
</details>
